@@ -2,7 +2,7 @@
 '''AlazarTech Package Registration Script
 
 Usage:
-  register [--dev] [--dry-run] [-p <passfile>] <endpoint> <specfile> <base_url> <version>
+  register [--dev] [--dry-run] [--email-notif] [-p <passfile>] <endpoint> <specfile> <base_url> <version>
   register -h | --help
   register --version
 
@@ -14,6 +14,8 @@ Options:
                  instead of the release version.
   --dry-run      Performs a practice run of the operation, without actually
                  sending an HTTP request to the website.
+  --email-notif  Send an email notification to <marketing@alazartech.com> after 
+                 succesfull package registration.
 
 Arguments:
   <endpoint>      Enpoint where to send request payload.
@@ -27,6 +29,8 @@ Arguments:
 
 import os
 
+import smtplib
+
 import json
 from collections import namedtuple
 
@@ -96,6 +100,13 @@ PRODUCTS = {
     "ATST371": '1044',
     "ATST352": '1045',
     "ATST146": '1046',
+    # Negative product IDs are for products that we want to send to the website 
+    # but are to be associated with other products. For instance, some packages 
+    # are to be sent to Linux drivers resources.
+    "libats": '-1',
+    "Alazar-Front-Panel": '-2',
+    "Firmware Update Utility (CLI)": '-3',
+    "Firmware Update Utility (GUI)": '-4',
 }
 
 # Identifies a package that can be registered to the website
@@ -135,6 +146,29 @@ def get_arch(filename):
     else:
         return 'x86_64'
 
+def is_driver(key):
+    driver_infix = tuple('0123456789T')
+    for c in driver_infix:
+        if key.startswith("ATS"+c):
+            return True
+    return False
+
+def get_name(packageid):
+    if is_driver(packageid.key):
+        if packageid.os == 'Windows':
+            return packageid.key + " " + packageid.arch + " driver for Windows"
+        elif packageid.os == 'Linux (.deb)' or packageid.os == 'Linux (.rpm)':
+            return packageid.key + " " + packageid.arch + " driver for Linux"
+    return packageid.key
+
+def get_category(key):
+    if is_driver(key):
+        return 'driver'
+    elif key == "Firmware Update Utility (CLI)" or \
+         key == "Firmware Update Utility (GUI)":
+        return 'utility'
+    else:
+        return 'software'
 
 def get_product_key(filename):
     for key in PRODUCTS:
@@ -153,6 +187,7 @@ Package = namedtuple(
         'readme',  # type: str
         'name',  # type: str
         'arch',  # type: str
+        'category',  # type: str
     ])
 
 
@@ -185,10 +220,21 @@ def packages_from_files(files):
                     product_id=PRODUCTS[packageid.key],
                     installer=installers[packageid],
                     readme=readmes[packageid.key],
-                    name=packageid.key,
-                    arch=packageid.arch))
+                    name=get_name(packageid),
+                    arch=packageid.arch,
+                    category=get_category(packageid.key)))
     return packages
 
+# Packages to be sent to Linux drivers resources.
+def is_linux_resource(package):
+    if package.os != 'Linux (.deb)' and package.os != 'Linux (.rpm)':
+        return False
+    if package.name == 'libats' or \
+       package.name == 'Alazar-Front-Panel' or \
+       package.name == 'Firmware Update Utility (CLI)' or \
+       package.name == 'Firmware Update Utility (GUI)':
+        return True
+    return False
 
 def payload_from_packages(packages, base_url, version, password):
     if not base_url.endswith('/'):
@@ -197,20 +243,51 @@ def payload_from_packages(packages, base_url, version, password):
         password = ""
     payload = []
     for package in packages:
-        payload.append({
-            "os": package.os,
-            "product_id": package.product_id,
-            "url": base_url + package.installer,
-            "release_notes_url": base_url + package.readme,
-            "version": version,
-            "password": password,
-            "name": package.name,
-            "arch": package.arch,
-        })
+        if is_linux_resource(package):
+            for key in PRODUCTS:
+                if is_driver(key):
+                    payload.append({
+                        "os": package.os,
+                        "product_id": PRODUCTS[key].product_id,
+                        "url": base_url + package.installer,
+                        "release_notes_url": base_url + package.readme,
+                        "version": version,
+                        "password": password,
+                        "name": package.name,
+                        "arch": package.arch,
+                        "category": package.category,
+                    })
+        elif package.product_id > 0:
+            payload.append({
+                "os": package.os,
+                "product_id": package.product_id,
+                "url": base_url + package.installer,
+                "release_notes_url": base_url + package.readme,
+                "version": version,
+                "password": password,
+                "name": package.name,
+                "arch": package.arch,
+                "category": package.category,
+            })
     return json.dumps(payload)
 
+def send_email_notif(url_endpoint):
+    server = smtplib.SMTP('smtp.videotron.ca')
+    
+    message = """\
+    Subject: New product release
+    From: GitLab <gitlab@gitlab.alazartech.com>
+    To: Marketing <marketing@alazartech.com>
 
-def register(endpoint, development, passfile, specsfile, baseurl, version, dry_run):
+    Hi there! 
+
+    A new product sent to """ + url_endpoint + """ is now ready for release."""
+
+    server.sendmail("gitlab@gitlab.alazartech.com", "marketing@alazartech.com", message)
+    server.quit()
+
+
+def register(endpoint, development, passfile, specsfile, baseurl, version, dry_run, email_notif):
     specs = get_specs_from_file(specsfile)
     files = [thing for spec in specs for thing in get_things(spec)]
     packages = packages_from_files(files)
@@ -235,6 +312,8 @@ def register(endpoint, development, passfile, specsfile, baseurl, version, dry_r
     if res.status_code != 200:
         raise ValueError("Registration request returned status code {}".format(
             res.status_code))
+    if email_notif:
+        send_email_notif(url_endpoint)
 
 
 def main():
@@ -246,7 +325,8 @@ def main():
              specsfile=arguments['<specfile>'],
              baseurl=arguments['<base_url>'],
              version=arguments['<version>'],
-             dry_run=arguments['--dry-run'])
+             dry_run=arguments['--dry-run'],
+             email_notif=arguments['--email-notif'])
 
 if __name__ == "__main__":
     main()
